@@ -127,22 +127,24 @@ pub enum RpcError {
     #[error("provider initialization or put-link: {0}")]
     ProviderInit(String),
 
+    //#[error("IO error")]
+    //IO([from] std::io::Error)
     /// Anything else
     #[error("{0}")]
     Other(String),
 }
 
-impl From<String> for RpcError {
-    fn from(s: String) -> RpcError {
-        RpcError::Other(s)
-    }
-}
-
-impl From<&str> for RpcError {
-    fn from(s: &str) -> RpcError {
-        RpcError::Other(s.to_string())
-    }
-}
+//impl From<String> for RpcError {
+//    fn from(s: String) -> RpcError {
+//        RpcError::Other(s)
+//    }
+//}
+//
+//impl From<&str> for RpcError {
+//    fn from(s: &str) -> RpcError {
+//        RpcError::Other(s.to_string())
+//    }
+//}
 
 #[async_trait]
 pub trait MessageDispatch {
